==> nextcloud-app-tasks-0.11.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/bg.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Задачи",
    "Important" : "Важно",
    "Today" : "Днес",
    "Week" : "Седмица",
    "All" : "Всички",
    "Current" : "Текущ",
    "Completed" : "Завършено",
    "The Tasks app for Nextcloud" : "Задачи за NextCloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates, reminder times, mark them as important, and add comments on them. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal... - just add the calendar as a remote calendar in you client). You can download your tasks as ICS files using the download button for each calendar." : "След като бъде активиран, ще се бъде добавено \"Задачи\" в менюто с приложения на на NextCloud. От там ще може да добавяте или изтривате задачи, редактиране на заглавието им, описание, начална и крайна дата, време за напомняне, да ги маркирате като важни и да добавяте коментари към тях. Задачите могат да се споделят между потребителите. Задачите могат да бъдат синхронизирани чрез CalDav (всеки списък със задачи е свързан с календарa Nextcloud, за да го синхронизирате с локалния си клиент - Thunderbird, Evolution, KDE Kontact, iCal ... - просто добавете календара като отдалечен календар в клиента си). Можете да изтеглите задачите си като ICS файлове, като използвате бутона за изтегляне за всеки календар.",
    "can edit" : "може да редактира",
    "Delete" : "Изтриване",
    "Cancel" : "Отказ",
    "Load all completed tasks." : "Зареди всички завършени задачи.",
    "Change sort order" : "Промени подредбата",
    "Default" : "Стандартно",
    "Due date" : "Крайна дата",
    "Start date" : "Начална дата",
    "Created date" : "Създадена",
    "Last modified" : "Променена",
    "Priority" : "Приоритет",
    "Manually" : "Ръчно",
    "Alphabetically" : "По азбучен ред",
    "Task is completed" : "Задачата е завършена",
    "{complete} % completed" : "{complete} % завършени",
    "[Yesterday]" : "[вчера]",
    "[Today]" : "[днес]",
    "[Tomorrow]" : "[утре]",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Завършена задача","%n Завършени задачи"],
    "Tomorrow" : "Утре",
    "Set start date" : "Начална дата",
    "Set start time" : "Начална дата",
    "Set due date" : "Крайна дата",
    "Set due time" : "Крайна дата",
    "All day" : "Цял ден",
    "Select a calendar" : "Избор на календар",
    "Select categories" : "Избор на категории",
    "Add this as a new category" : "Добави като нова категория",
    "Task not found!" : "Задачата не е намерена!",
    "Edit" : "Редакция",
    "Download" : "Изтегляне",
    "Save" : "Запазване",
    "New List" : "Нов списък",
    "An empty name is not allowed." : "Празно име не е разрешено.",
    "Settings" : "Настройки",
    "Visibility of Smart Collections" : "Видимост на \"Smart\" колекции",
    "Hidden" : "Скрито",
    "Visible" : "Видимо",
    "Automatic" : "Автоматично"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.12.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/bg.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Важно",
    "Today" : "Днес",
    "Week" : "Седмица",
    "All" : "Всички",
    "Current" : "Текущ",
    "Completed" : "Завършено",
    "Tasks" : "Задачи",
    "The Tasks app for Nextcloud" : "Задачи за NextCloud",
    "Share with users or groups" : "Сподели с потребители или групи",
    "can edit" : "може да редактира",
    "New List" : "Нов списък",
    "Cancel" : "Отказ",
    "Save" : "Запазване",
    "An empty name is not allowed." : "Празно име не е разрешено.",
    "Edit" : "Редакция",
    "Copy private link" : "Копирай скритата връзка",
    "Download" : "Изтегляне",
    "Delete" : "Изтриване",
    "Unshare" : "Прекрати споделянето",
    "Calendar link copied to clipboard." : "Копирано в клипборда",
    "Visibility of Smart Collections" : "Видимост на \"Smart\" колекции",
    "Hidden" : "Скрито",
    "Visible" : "Видимо",
    "Automatic" : "Автоматично",
    "No errors" : "Няма грешки",
    "Load all completed tasks." : "Зареди всички завършени задачи.",
    "Change sort order" : "Промени подредбата",
    "Start date" : "Начална дата",
    "Due date" : "Крайна дата",
    "Created date" : "Създадена",
    "Last modified" : "Променена",
    "Priority" : "Приоритет",
    "Manually" : "Ръчно",
    "Alphabetically" : "По азбучен ред",
    "Task is completed" : "Задачата е завършена",
    "{complete} % completed" : "{complete} % завършени",
    "[Yesterday]" : "[вчера]",
    "[Today]" : "[днес]",
    "[Tomorrow]" : "[утре]",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Завършена задача","%n Завършени задачи"],
    "Tomorrow" : "Утре",
    "Set start date" : "Начална дата",
    "Set start time" : "Начална дата",
    "Set due date" : "Крайна дата",
    "Set due time" : "Крайна дата",
    "All day" : "Цял ден",
    "Select a calendar" : "Избор на календар",
    "Select categories" : "Избор на категории",
    "Add this as a new category" : "Добави като нова категория",
    "Task not found!" : "Задачата не е намерена!",
    "When shared show full event" : "При споделяне, показвай цялото събитие",
    "When shared show only busy" : "При споделяне, показвай само статус \"зает\"",
    "When shared hide this event" : "При споделяне, скривай това събитие",
    "An error occurred" : "Възникна грешка"
},
"nplurals=2; plural=(n != 1);");
